@@ -5,7 +5,7 @@ const Mainloop = imports.mainloop;
 const Tweener = imports.tweener.tweener;
 
 // gi imports
-const Tb = imports.gi.Tb;
+const TheBoard = imports.gi.TheBoard;
 const Clutter = imports.gi.Clutter;
 const Gdk = imports.gi.Gdk;
 const GIO = imports.gi.Gio;
@@ -14,14 +14,13 @@ const GtkClutter = imports.gi.GtkClutter;
 const Mx = imports.gi.Mx;
 
 // ui imports
+const MainToolbar = imports.ui.mainToolbar;
 const Page = imports.ui.page;
 const PhotoThing = imports.ui.things.photo;
+const SelectionToolbar = imports.ui.selectionToolbar;
 const Thing = imports.ui.thing;
 const ToolBox = imports.ui.toolBox;
-const ToolBoxBackgrounds = imports.ui.toolBoxBackgrounds;
 const Toolbar = imports.ui.toolbar;
-const ToolBoxPages = imports.ui.toolBoxPages;
-const ToolBoxThings = imports.ui.toolBoxThings;
 
 // model imports
 const PageManager = imports.model.pageManager;
@@ -83,12 +82,10 @@ MainWindow.prototype = {
 
         this._gtkWindow =
             new Gtk.Window({ type: Gtk.WindowType.TOPLEVEL,
-                             typeHint: Gdk.WindowTypeHint.DIALOG,
-                             windowPosition: Gtk.WindowPosition.CENTER_ALWAYS,
+                             typeHint: Gdk.WindowTypeHint.NORMAL,
                              title: "The Board",
                              focusOnMap: true,
                              hasResizeGrip: false,
-                             decorated: false,
                              deletable: false,
                              skipTaskbarHint: false,
                              skipPagerHint: false });
@@ -145,11 +142,11 @@ MainWindow.prototype = {
 
     _createMainBox : function() {
         this._mainBox =
-            new Tb.Box({ orientation: Tb.BoxOrientation.VERTICAL,
-                         xAlign: Tb.BoxAlignment.FILL,
-                         yAlign: Tb.BoxAlignment.FILL,
-                         reactive: true,
-                         name: "main-window-main-box" });
+            new TheBoard.Box({ orientation: TheBoard.BoxOrientation.VERTICAL,
+                               xAlign: TheBoard.BoxAlignment.FILL,
+                               yAlign: TheBoard.BoxAlignment.FILL,
+                               reactive: true,
+                               name: "main-window-main-box" });
 
         this._stage.add_actor(this._mainBox);
         this._stage.show();
@@ -169,23 +166,23 @@ MainWindow.prototype = {
 
     _createContentBox : function() {
         this._contentBox =
-            new Tb.Box({ orientation: Tb.BoxOrientation.VERTICAL,
-                         xAlign: Tb.BoxAlignment.FILL,
-                         yAlign: Tb.BoxAlignment.FILL,
-                         clipToAllocation: true,
-                         name: "main-window-content-box" });
+            new TheBoard.Box({ orientation: TheBoard.BoxOrientation.VERTICAL,
+                               xAlign: TheBoard.BoxAlignment.FILL,
+                               yAlign: TheBoard.BoxAlignment.FILL,
+                               clipToAllocation: true,
+                               name: "main-window-content-box" });
 
         this._mainBox.append(this._contentBox,
-                             Tb.BoxPackFlags.EXPAND);
+                             TheBoard.BoxPackFlags.EXPAND);
     },
 
     _createStartupBox : function() {
         this._startupBox =
-            new Tb.Box({ orientation: Tb.BoxOrientation.VERTICAL,
-                         xAlign: Tb.BoxAlignment.CENTER,
-                         yAlign: Tb.BoxAlignment.CENTER,
-                         reactive: true,
-                         name: "main-window-startup-box" });
+            new TheBoard.Box({ orientation: TheBoard.BoxOrientation.VERTICAL,
+                               xAlign: TheBoard.BoxAlignment.CENTER,
+                               yAlign: TheBoard.BoxAlignment.CENTER,
+                               reactive: true,
+                               name: "main-window-startup-box" });
 
         let text = Gettext.gettext("The Board is loading. Just a sec.");
 
@@ -194,14 +191,14 @@ MainWindow.prototype = {
                            name: "main-window-startup-label" });
 
         this._startupBox.append(this._startupText,
-                                Tb.BoxPackFlags.NONE);
+                                TheBoard.BoxPackFlags.NONE);
 
         this._mainBox.append(this._startupBox,
-                             Tb.BoxPackFlags.FIXED);
+                             TheBoard.BoxPackFlags.FIXED);
 
         this._mainBox.set_fixed_child_align(this._startupBox,
-                                            Tb.BoxAlignment.FILL,
-                                            Tb.BoxAlignment.FILL);
+                                            TheBoard.BoxAlignment.FILL,
+                                            TheBoard.BoxAlignment.FILL);
 
         this._startupBoxTimeoutId =
             Mainloop.timeout_add_seconds(1, Lang.bind(this,
@@ -209,138 +206,43 @@ MainWindow.prototype = {
     },
 
     _createMainToolbar : function() {
-        this._mainToolbar = new Toolbar.Toolbar();
+        this._mainToolbar =
+            new MainToolbar.MainToolbar({ context: this._context });
 
-        this._mainToolbar.actor.depth = _LAYER_TOOLBAR;
-
-        this._createToolBoxPages();
-        this._createToolBoxThings();
-        this._createToolBoxBackgrounds();
-
-        this._contentBox.append(this._mainToolbar.actor,
-                                Tb.BoxPackFlags.FIXED);
-
-        this._contentBox.set_fixed_child_align(this._mainToolbar.actor,
-                                               Tb.BoxAlignment.CENTER,
-                                               Tb.BoxAlignment.START);
+        this._appendToolbar(this._mainToolbar);
 
         this._updateActiveToolbar();
     },
 
     _createSelectionToolbar : function() {
         this._selectionToolbar =
-            new Toolbar.Toolbar({ title: Gettext.gettext("Selection"),
-                                  visible: false });
+            new SelectionToolbar.SelectionToolbar({ title: Gettext.gettext("Selection"),
+                                                    visible: false });
 
-        this._selectionToolbar.actor.depth = _LAYER_TOOLBAR;
-
-        this._createToolBoxAlign();
-        this._createToolBoxDistribute();
-        this._createToolBoxRemove();
-
-        this._contentBox.append(this._selectionToolbar.actor,
-                                Tb.BoxPackFlags.FIXED);
-
-        this._contentBox.set_fixed_child_align(this._selectionToolbar.actor,
-                                               Tb.BoxAlignment.CENTER,
-                                               Tb.BoxAlignment.START);
+        this._appendToolbar(this._selectionToolbar);
     },
 
     _createSpinner : function() {
         this._spinnerBox =
-            new Tb.Box({ orientation: Tb.BoxOrientation.VERTICAL,
-                         xAlign: Tb.BoxAlignment.CENTER,
-                         yAlign: Tb.BoxAlignment.CENTER,
-                         visible: false, // starts hidden
-                         name: "main-window-spinner-box" });
+            new TheBoard.Box({ orientation: TheBoard.BoxOrientation.VERTICAL,
+                               xAlign: TheBoard.BoxAlignment.CENTER,
+                               yAlign: TheBoard.BoxAlignment.CENTER,
+                               visible: false, // starts hidden
+                               name: "main-window-spinner-box" });
 
         this._spinner = new Mx.Spinner({ width: _SPINNER_SIZE,
                                          height: _SPINNER_SIZE,
                                          name: "main-window-spinner" });
 
         this._spinnerBox.append(this._spinner,
-                                Tb.BoxPackFlags.NONE);
+                                TheBoard.BoxPackFlags.NONE);
 
         this._mainBox.append(this._spinnerBox,
-                                Tb.BoxPackFlags.FIXED);
+                                TheBoard.BoxPackFlags.FIXED);
 
         this._mainBox.set_fixed_child_align(this._spinnerBox,
-                                            Tb.BoxAlignment.END,
-                                            Tb.BoxAlignment.START);
-    },
-
-    _createToolBoxPages : function() {
-        this._toolBoxPages =
-            new ToolBoxPages.ToolBoxPages({ context: this._context });
-
-        this._mainToolbar.addToolBox(this._toolBoxPages);
-    },
-
-    _createToolBoxAlign : function() {
-        this._toolBoxAlign =
-            new ToolBox.ToolBox({ title: Gettext.gettext("Align") });
-
-        this._toolBoxAlign.addButton({ label: Gettext.gettext("Left"),
-                                       actionName: "align",
-                                       actionArgs: { alignment: Page.Alignment.LEFT } });
-
-        this._toolBoxAlign.addButton({ label: Gettext.gettext("Right"),
-                                       actionName: "align",
-                                       actionArgs: { alignment: Page.Alignment.RIGHT } });
-
-        this._toolBoxAlign.addButton({ label: Gettext.gettext("Top"),
-                                       actionName: "align",
-                                       actionArgs: { alignment: Page.Alignment.TOP } });
-
-        this._toolBoxAlign.addButton({ label: Gettext.gettext("Bottom"),
-                                       actionName: "align",
-                                       actionArgs: { alignment: Page.Alignment.BOTTOM } });
-
-        this._selectionToolbar.addToolBox(this._toolBoxAlign);
-    },
-
-    _createToolBoxDistribute : function() {
-        this._toolBoxDistribute =
-            new ToolBox.ToolBox({ title: Gettext.gettext("Distribute") });
-
-        let verticalArgs =
-            { label: Gettext.gettext("Vertical"),
-              actionName: "distribute",
-              actionArgs: { orientation: Page.Orientation.VERTICAL } };
-
-        this._toolBoxDistribute.addButton(verticalArgs);
-
-        let horizontalArgs =
-            { label: Gettext.gettext("Horizontal"),
-              actionName: "distribute",
-              actionArgs: { orientation: Page.Orientation.HORIZONTAL } };
-
-        this._toolBoxDistribute.addButton(horizontalArgs);
-
-        this._selectionToolbar.addToolBox(this._toolBoxDistribute);
-    },
-
-    _createToolBoxRemove : function() {
-        this._toolBoxRemove = new ToolBox.ToolBox();
-
-        this._toolBoxRemove.addButton({ label: Gettext.gettext("Remove"),
-                                        actionName: "remove" });
-
-        this._selectionToolbar.addToolBox(this._toolBoxRemove);
-    },
-
-    _createToolBoxThings : function() {
-        this._toolBoxThings =
-            new ToolBoxThings.ToolBoxThings({ mainWindow: this });
-
-        this._mainToolbar.addToolBox(this._toolBoxThings);
-    },
-
-    _createToolBoxBackgrounds : function() {
-        this._toolBoxBackgrounds =
-            new ToolBoxBackgrounds.ToolBoxBackgrounds({ mainWindow: this });
-
-        this._mainToolbar.addToolBox(this._toolBoxBackgrounds);
+                                            TheBoard.BoxAlignment.END,
+                                            TheBoard.BoxAlignment.START);
     },
 
     _createContext : function() {
@@ -376,11 +278,11 @@ MainWindow.prototype = {
         pageTurn.set_resolution(64, 64);
 
         this._mainBox.append(pageTurn,
-                             Tb.BoxPackFlags.FIXED);
+                             TheBoard.BoxPackFlags.FIXED);
 
         this._mainBox.set_fixed_child_align(pageTurn,
-                                            Tb.BoxAlignment.FILL,
-                                            Tb.BoxAlignment.FILL);
+                                            TheBoard.BoxAlignment.FILL,
+                                            TheBoard.BoxAlignment.FILL);
 
         let onComplete = function() {
             delete this._startupBox;
@@ -406,6 +308,17 @@ MainWindow.prototype = {
                            onComplete: Lang.bind(this, onComplete) });
     },
 
+    _appendToolbar : function(toolbar) {
+        toolbar.actor.depth = _LAYER_TOOLBAR;
+
+        this._contentBox.append(toolbar.actor,
+                                TheBoard.BoxPackFlags.FIXED);
+
+        this._contentBox.set_fixed_child_align(toolbar.actor,
+                                               TheBoard.BoxAlignment.CENTER,
+                                               TheBoard.BoxAlignment.START);
+    },
+
     _setActiveToolbar : function(activeToolbar) {
         if (this._activeToolbar == activeToolbar) {
             return;
@@ -484,16 +397,8 @@ MainWindow.prototype = {
                                      { mainWindow: this });
 
         if (thingToolbar) {
-            thingToolbar.actor.depth = _LAYER_TOOLBAR;
-
+            this._appendToolbar(thingToolbar);
             this._toolbarsByThingId[thingId] = thingToolbar;
-
-            this._contentBox.append(thingToolbar.actor,
-                                    Tb.BoxPackFlags.FIXED);
-
-            this._contentBox.set_fixed_child_align(thingToolbar.actor,
-                                                   Tb.BoxAlignment.CENTER,
-                                                   Tb.BoxAlignment.START);
         }
 
         return thingToolbar;
@@ -600,7 +505,7 @@ MainWindow.prototype = {
         this._setAnimatingPageTurn(true);
 
         this._contentBox.append(newPage.actor,
-                                Tb.BoxPackFlags.EXPAND);
+                                TheBoard.BoxPackFlags.EXPAND);
 
         let pageTurn = new Mx.DeformPageTurn({ radius: 40.0,
                                                angle: 0.80 });
@@ -615,11 +520,11 @@ MainWindow.prototype = {
         pageTurn.set_resolution(64, 64);
 
         this._contentBox.append(pageTurn,
-                                Tb.BoxPackFlags.FIXED);
+                                TheBoard.BoxPackFlags.FIXED);
 
         this._contentBox.set_fixed_child_align(pageTurn,
-                                               Tb.BoxAlignment.FILL,
-                                               Tb.BoxAlignment.FILL);
+                                               TheBoard.BoxAlignment.FILL,
+                                               TheBoard.BoxAlignment.FILL);
 
         pageTurn.raise(newPage.actor);
 
@@ -664,11 +569,11 @@ MainWindow.prototype = {
         pageTurn.set_resolution(64, 64);
 
         this._contentBox.append(pageTurn,
-                                Tb.BoxPackFlags.FIXED);
+                                TheBoard.BoxPackFlags.FIXED);
 
         this._contentBox.set_fixed_child_align(pageTurn,
-                                               Tb.BoxAlignment.FILL,
-                                               Tb.BoxAlignment.FILL);
+                                               TheBoard.BoxAlignment.FILL,
+                                               TheBoard.BoxAlignment.FILL);
 
         pageTurn.raise(oldPage.actor);
 
@@ -684,7 +589,7 @@ MainWindow.prototype = {
             newPage.actor.reparent(this._contentBox);
 
             this._contentBox.set_child_packing(newPage.actor,
-                                               Tb.BoxPackFlags.EXPAND);
+                                               TheBoard.BoxPackFlags.EXPAND);
 
             pageTurn.destroy();
 
@@ -700,6 +605,82 @@ MainWindow.prototype = {
                            onComplete: Lang.bind(this, onComplete) });
     },
 
+    _doAction : function(actionName, actionArgs) {
+        if (actionName == "setCurrentPage") {
+            this._setCurrentPage(actionArgs.pageModel);
+        } else if (actionName == "setBackground") {
+            this._currentPage.setBackground(actionArgs.backgroundId);
+        } else if (actionName == "addThing") {
+            this._currentPage.addThingFromState({ id: actionArgs.thingId });
+        }
+    },
+
+    _setCurrentPage : function(pageModel) {
+        if (this._currentPage &&
+            this._currentPage.model.id == pageModel.id) {
+            return;
+        }
+
+        let oldCurrentPage = this._currentPage;
+
+        if (oldCurrentPage) {
+            oldCurrentPage.disconnect(this._pageActiveThingChangedId);
+            delete this._pageActiveThingChangedId;
+
+            oldCurrentPage.disconnect(this._pageClickedId);
+            delete this._pageClickedId;
+
+            oldCurrentPage.disconnect(this._pageLoadedChangedId);
+            delete this._pageLoadedChangedId;
+
+            oldCurrentPage.disconnect(this._pageSelectedThingsChangedId);
+            delete this._pageSelectedThingsChangedId;
+        }
+
+        this._currentPage = new Page.Page({ context: this._context,
+                                            model: pageModel });
+
+        this._mainToolbar.toolBoxPages.setCurrentPage(pageModel);
+
+        this._currentPage.actor.depth = _LAYER_PAGE;
+
+        this._pageActiveThingChangedId =
+            this._currentPage.connect("active-thing-changed",
+                                      Lang.bind(this, this._onPageActiveThingChanged));
+
+        this._pageClickedId =
+            this._currentPage.connect("clicked",
+                                      Lang.bind(this, this._onPageClicked));
+
+        this._pageLoadedChangedId =
+            this._currentPage.connect("loaded-changed",
+                                      Lang.bind(this, this._onPageLoadedChanged));
+
+        this._pageSelectedThingsChangedId =
+            this._currentPage.connect("selected-things-changed",
+                                      Lang.bind(this, this._onPageSelectedThingsChanged));
+
+        if (oldCurrentPage) {
+            let onModelSaved = function() {
+                this._setSavingOldCurrentPage(false);
+
+                if (this._currentPage.model.id > oldCurrentPage.model.id) {
+                    this._animateNextPage(this._currentPage, oldCurrentPage);
+                } else {
+                    this._animatePreviousPage(this._currentPage, oldCurrentPage);
+                }
+            };
+
+            this._setSavingOldCurrentPage(true);
+            oldCurrentPage.model.save(Lang.bind(this, onModelSaved));
+        } else {
+            this._contentBox.append(this._currentPage.actor,
+                                    TheBoard.BoxPackFlags.EXPAND);
+        }
+
+        this._updateLoadingState();
+    },
+
     _quitApp : function() {
         let onModelSaved = function() {
             this._setSavingOldCurrentPage(false);
@@ -715,7 +696,7 @@ MainWindow.prototype = {
     },
 
     _pasteClipboardContent : function() {
-        let clipboard = Tb.get_default_clipboard();
+        let clipboard = TheBoard.get_default_clipboard();
 
         let onTextReceived = Lang.bind(this,
                                        this._onClipboardTextReceived);
@@ -750,8 +731,7 @@ MainWindow.prototype = {
 
     _onToolbarAction : function(toolbar, actionName, actionArgs) {
         if (toolbar == this._mainToolbar) {
-            // FIXME: convert main toolbox group to use actions
-            // instead of internally hardcoded handlers
+            this._doAction(actionName, actionArgs);
             return;
         }
 
@@ -815,8 +795,6 @@ MainWindow.prototype = {
         } else if (key == Clutter.Escape) {
             if (this._currentPage.selectedThings.length > 0) {
                 this._currentPage.unselectAllThings();
-            } else {
-                this._hideGtkWindow();
             }
         } else if (text == 't') {
             this._currentPage.addThingFromState({ id: 'note' });
@@ -833,9 +811,36 @@ MainWindow.prototype = {
         } else if (text == 's') {
             this._currentPage.addThingFromState({ id: 'sound' });
             return true;
-        } else if (text == 'q') {
+        } else if (isControl && text == 'w') {
+            this._hideGtkWindow();
+            return true;
+        } else if (isControl && text == 'q') {
             this._quitApp();
             return true;
+        } else if (isControl && text == 'h') {
+            this._currentPage.doAction("distribute",
+                                       { orientation: Page.Orientation.HORIZONTAL });
+            return true;
+        } else if (isControl && text == 'g') {
+            this._currentPage.doAction("distribute",
+                                       { orientation: Page.Orientation.VERTICAL });
+            return true;
+        } else if (isControl && text == 'u') {
+            this._currentPage.doAction("align",
+                                       { alignment: Page.Alignment.LEFT });
+            return true;
+        } else if (isControl && text == 'i') {
+            this._currentPage.doAction("align",
+                                       { alignment: Page.Alignment.RIGHT });
+            return true;
+        } else if (isControl && text == 'j') {
+            this._currentPage.doAction("align",
+                                       { alignment: Page.Alignment.TOP });
+            return true;
+        } else if (isControl && text == 'k') {
+            this._currentPage.doAction("align",
+                                       { alignment: Page.Alignment.BOTTOM });
+            return true;
         }
 
         return false;
@@ -853,7 +858,7 @@ MainWindow.prototype = {
                 pageModel = this._pageManager.addPageModel();
             }
 
-            this.setCurrentPage(pageModel);
+            this._setCurrentPage(pageModel);
         }
     },
 
@@ -879,7 +884,7 @@ MainWindow.prototype = {
             // once model of current page is loaded, it's safe to
             // update tool box with current state
             let backgroundId = this._currentPage.model.background;
-            this._toolBoxBackgrounds.setCurrentBackground(backgroundId);
+            this._mainToolbar.toolBoxBackgrounds.setCurrentBackground(backgroundId);
         }
     },
 
@@ -887,72 +892,6 @@ MainWindow.prototype = {
         this._updateActiveToolbar();
     },
 
-    setCurrentPage : function(pageModel) {
-        if (this._currentPage &&
-            this._currentPage.model.id == pageModel.id) {
-            return;
-        }
-
-        let oldCurrentPage = this._currentPage;
-
-        if (oldCurrentPage) {
-            oldCurrentPage.disconnect(this._pageActiveThingChangedId);
-            delete this._pageActiveThingChangedId;
-
-            oldCurrentPage.disconnect(this._pageClickedId);
-            delete this._pageClickedId;
-
-            oldCurrentPage.disconnect(this._pageLoadedChangedId);
-            delete this._pageLoadedChangedId;
-
-            oldCurrentPage.disconnect(this._pageSelectedThingsChangedId);
-            delete this._pageSelectedThingsChangedId;
-        }
-
-        this._currentPage = new Page.Page({ context: this._context,
-                                            model: pageModel });
-
-        this._toolBoxPages.setCurrentPage(pageModel);
-
-        this._currentPage.actor.depth = _LAYER_PAGE;
-
-        this._pageActiveThingChangedId =
-            this._currentPage.connect("active-thing-changed",
-                                      Lang.bind(this, this._onPageActiveThingChanged));
-
-        this._pageClickedId =
-            this._currentPage.connect("clicked",
-                                      Lang.bind(this, this._onPageClicked));
-
-        this._pageLoadedChangedId =
-            this._currentPage.connect("loaded-changed",
-                                      Lang.bind(this, this._onPageLoadedChanged));
-
-        this._pageSelectedThingsChangedId =
-            this._currentPage.connect("selected-things-changed",
-                                      Lang.bind(this, this._onPageSelectedThingsChanged));
-
-        if (oldCurrentPage) {
-            let onModelSaved = function() {
-                this._setSavingOldCurrentPage(false);
-
-                if (this._currentPage.model.id > oldCurrentPage.model.id) {
-                    this._animateNextPage(this._currentPage, oldCurrentPage);
-                } else {
-                    this._animatePreviousPage(this._currentPage, oldCurrentPage);
-                }
-            };
-
-            this._setSavingOldCurrentPage(true);
-            oldCurrentPage.model.save(Lang.bind(this, onModelSaved));
-        } else {
-            this._contentBox.append(this._currentPage.actor,
-                                    Tb.BoxPackFlags.EXPAND);
-        }
-
-        this._updateLoadingState();
-    },
-
     showAll : function() {
         this._gtkWindow.show_all();
     },
