@@ -5,13 +5,13 @@ const Mainloop = imports.mainloop;
 const Tweener = imports.tweener.tweener;
 
 // gi imports
-const Tb = imports.gi.Tb;
 const Clutter = imports.gi.Clutter;
 const GIO = imports.gi.Gio;
 const GLib = imports.gi.GLib;
 const Gtk = imports.gi.Gtk;
 const Mx = imports.gi.Mx;
 const Pango = imports.gi.Pango;
+const TheBoard = imports.gi.TheBoard;
 
 // ui imports
 const Thing = imports.ui.thing;
@@ -70,10 +70,10 @@ SoundThing.prototype = {
 
     _createSoundBox : function() {
         this._soundBox =
-            new Tb.Box({ orientation: Tb.BoxOrientation.HORIZONTAL,
-                         xAlign: Tb.BoxAlignment.FILL,
-                         yAlign: Tb.BoxAlignment.FILL,
-                         name: "sound-thing-sound-box" });
+            new TheBoard.Box({ orientation: TheBoard.BoxOrientation.HORIZONTAL,
+                               xAlign: TheBoard.BoxAlignment.FILL,
+                               yAlign: TheBoard.BoxAlignment.FILL,
+                               name: "sound-thing-sound-box" });
 
         this._soundBox.set_style(this._style);
 
@@ -82,7 +82,7 @@ SoundThing.prototype = {
     },
 
     _createSoundPlayer : function() {
-        this._player = new Tb.SoundPlayer();
+        this._player = new TheBoard.SoundPlayer();
 
         this._player.connect("notify::progress",
                              Lang.bind(this,
@@ -102,34 +102,34 @@ SoundThing.prototype = {
             new Clutter.Texture({ filename: _CASSETE_IMAGE });
 
         this._soundBox.append(this._casseteBg,
-                              Tb.BoxPackFlags.FIXED);
+                              TheBoard.BoxPackFlags.FIXED);
 
         this._soundBox.set_fixed_child_align(this._casseteBg,
-                                             Tb.BoxAlignment.FILL,
-                                             Tb.BoxAlignment.FILL);
+                                             TheBoard.BoxAlignment.FILL,
+                                             TheBoard.BoxAlignment.FILL);
     },
 
     _createContentBox : function() {
         this._contentBox =
-            new Tb.Box({ orientation: Tb.BoxOrientation.VERTICAL,
-                         xAlign: Tb.BoxAlignment.FILL,
-                         yAlign: Tb.BoxAlignment.FILL,
-                         name: "sound-thing-content-box" });
+            new TheBoard.Box({ orientation: TheBoard.BoxOrientation.VERTICAL,
+                               xAlign: TheBoard.BoxAlignment.FILL,
+                               yAlign: TheBoard.BoxAlignment.FILL,
+                               name: "sound-thing-content-box" });
 
         this._contentBox.set_style(this._style);
 
         this._createControlsBox();
 
         this._soundBox.append(this._contentBox,
-                                Tb.BoxPackFlags.EXPAND);
+                              TheBoard.BoxPackFlags.EXPAND);
     },
 
     _createControlsBox : function() {
         this._controlsBox =
-            new Tb.Box({ orientation: Tb.BoxOrientation.VERTICAL,
-                         xAlign: Tb.BoxAlignment.FILL,
-                         yAlign: Tb.BoxAlignment.START,
-                         name: "sound-thing-controls-box" });
+            new TheBoard.Box({ orientation: TheBoard.BoxOrientation.VERTICAL,
+                               xAlign: TheBoard.BoxAlignment.FILL,
+                               yAlign: TheBoard.BoxAlignment.START,
+                               name: "sound-thing-controls-box" });
 
         this._controlsBox.set_style(this._style);
 
@@ -137,21 +137,21 @@ SoundThing.prototype = {
         this._createTimeLabel();
 
         this._contentBox.append(this._controlsBox,
-                                Tb.BoxPackFlags.FIXED);
+                                TheBoard.BoxPackFlags.FIXED);
 
         this._contentBox.set_fixed_child_align(this._controlsBox,
-                                               Tb.BoxAlignment.FILL,
-                                               Tb.BoxAlignment.END);
+                                               TheBoard.BoxAlignment.FILL,
+                                               TheBoard.BoxAlignment.END);
     },
 
     _createPlaybackBox : function() {
         this._playbackBox =
-            new Tb.Box({ orientation: Tb.BoxOrientation.HORIZONTAL,
-                         xAlign: Tb.BoxAlignment.FILL,
-                         yAlign: Tb.BoxAlignment.CENTER,
-                         visible: false,
-                         opacity: 0,
-                         name: "sound-thing-playback-box" });
+            new TheBoard.Box({ orientation: TheBoard.BoxOrientation.HORIZONTAL,
+                               xAlign: TheBoard.BoxAlignment.FILL,
+                               yAlign: TheBoard.BoxAlignment.CENTER,
+                               visible: false,
+                               opacity: 0,
+                               name: "sound-thing-playback-box" });
 
         this._playbackBox.set_style(this._style);
 
@@ -159,7 +159,7 @@ SoundThing.prototype = {
         this._createProgressBar();
 
         this._controlsBox.append(this._playbackBox,
-                                 Tb.BoxPackFlags.NONE);
+                                 TheBoard.BoxPackFlags.NONE);
     },
 
     _createPlayButton : function() {
@@ -174,7 +174,7 @@ SoundThing.prototype = {
                                            this._onPlayButtonToggled));
 
         this._playbackBox.append(this._playButton,
-                                 Tb.BoxPackFlags.NONE);
+                                 TheBoard.BoxPackFlags.NONE);
     },
 
     _createProgressBar : function() {
@@ -192,11 +192,11 @@ SoundThing.prototype = {
                                             this._onProgressBarButtonPressEvent));
 
         this._playbackBox.append(this._progressBar,
-                                 Tb.BoxPackFlags.EXPAND);
+                                 TheBoard.BoxPackFlags.EXPAND);
 
         this._playbackBox.set_child_align(this._progressBar,
-                                          Tb.BoxAlignment.FILL,
-                                          Tb.BoxAlignment.CENTER);
+                                          TheBoard.BoxAlignment.FILL,
+                                          TheBoard.BoxAlignment.CENTER);
     },
 
     _createTimeLabel : function() {
@@ -212,19 +212,19 @@ SoundThing.prototype = {
         this._updateTimeLabel(this._player.duration);
 
         this._controlsBox.append(this._timeLabel,
-                                 Tb.BoxPackFlags.NONE);
+                                 TheBoard.BoxPackFlags.NONE);
 
         this._controlsBox.set_child_align(this._timeLabel,
-                                          Tb.BoxAlignment.CENTER,
-                                          Tb.BoxAlignment.END);
+                                          TheBoard.BoxAlignment.CENTER,
+                                          TheBoard.BoxAlignment.END);
     },
 
     _createCaptionText : function() {
         this._captionBox =
-            new Tb.Box({ orientation: Tb.BoxOrientation.HORIZONTAL,
-                         xAlign: Tb.BoxAlignment.FILL,
-                         yAlign: Tb.BoxAlignment.FILL,
-                         name: _CAPTION_BOX_STYLE_NORMAL });
+            new TheBoard.Box({ orientation: TheBoard.BoxOrientation.HORIZONTAL,
+                               xAlign: TheBoard.BoxAlignment.FILL,
+                               yAlign: TheBoard.BoxAlignment.FILL,
+                               name: _CAPTION_BOX_STYLE_NORMAL });
 
         this._captionBox.set_style(this._style);
 
@@ -245,19 +245,19 @@ SoundThing.prototype = {
                                                          this._onCaptionTextChanged));
 
         this._captionBox.append(this._captionLabel,
-                                Tb.BoxPackFlags.EXPAND);
+                                TheBoard.BoxPackFlags.EXPAND);
 
         this._contentBox.append(this._captionBox,
-                                Tb.BoxPackFlags.NONE);
+                                TheBoard.BoxPackFlags.NONE);
     },
 
     _createSpools : function() {
         this._spoolsBox =
-            new Tb.Box({ orientation: Tb.BoxOrientation.HORIZONTAL,
-                         y: _SPOOLS_Y,
-                         xAlign: Tb.BoxAlignment.FILL,
-                         yAlign: Tb.BoxAlignment.FILL,
-                         name: "sound-thing-spools-box" });
+            new TheBoard.Box({ orientation: TheBoard.BoxOrientation.HORIZONTAL,
+                               y: _SPOOLS_Y,
+                               xAlign: TheBoard.BoxAlignment.FILL,
+                               yAlign: TheBoard.BoxAlignment.FILL,
+                               name: "sound-thing-spools-box" });
 
         this._spoolsBox.set_style(this._style);
 
@@ -270,15 +270,15 @@ SoundThing.prototype = {
             spool.set_style(this._style);
 
             this._spoolsBox.append(spool,
-                                   Tb.BoxPackFlags.NONE);
+                                   TheBoard.BoxPackFlags.NONE);
         }
 
         this._contentBox.append(this._spoolsBox,
-                                Tb.BoxPackFlags.FIXED);
+                                TheBoard.BoxPackFlags.FIXED);
 
         this._contentBox.set_fixed_child_align(this._spoolsBox,
-                                               Tb.BoxAlignment.CENTER,
-                                               Tb.BoxAlignment.FIXED);
+                                               TheBoard.BoxAlignment.CENTER,
+                                               TheBoard.BoxAlignment.FIXED);
     },
 
     _updateSpinner : function() {
@@ -411,7 +411,7 @@ SoundThing.prototype = {
         }
 
         this._recorder =
-            new Tb.SoundRecorder({ filename: filename });
+            new TheBoard.SoundRecorder({ filename: filename });
 
         this._recorder.connect("notify::duration",
                                Lang.bind(this,
@@ -429,11 +429,11 @@ SoundThing.prototype = {
         this._stopButton.set_style(this._style);
 
         this._contentBox.append(this._stopButton,
-                                Tb.BoxPackFlags.FIXED);
+                                TheBoard.BoxPackFlags.FIXED);
 
         this._contentBox.set_fixed_child_align(this._stopButton,
-                                               Tb.BoxAlignment.CENTER,
-                                               Tb.BoxAlignment.FIXED);
+                                               TheBoard.BoxAlignment.CENTER,
+                                               TheBoard.BoxAlignment.FIXED);
 
         this._recorder.start();
 
@@ -496,9 +496,9 @@ SoundThing.prototype = {
         let parentDir = soundFile.get_parent();
 
         if (targetDir.equal(parentDir)) {
-            Tb.g_file_delete_async(soundFile, null,
-                                   function() {},
-                                   null);
+            TheBoard.g_file_delete_async(soundFile, null,
+                                         function() {},
+                                         null);
         }
     },
 
@@ -639,17 +639,17 @@ SoundThing.prototype = {
 
     _onPlayerStateChanged : function() {
         switch(this._player.state) {
-        case Tb.SoundPlayerState.IDLE:
+        case TheBoard.SoundPlayerState.IDLE:
             this._updateForSoundLoaded();
             this._updateTimeLabel(this._player.duration);
             break;
 
-        case Tb.SoundPlayerState.DONE:
+        case TheBoard.SoundPlayerState.DONE:
             this._updateTimeLabel(this._player.duration);
             this._playButton.toggled = false;
             break;
 
-        case Tb.SoundPlayerState.ERROR:
+        case TheBoard.SoundPlayerState.ERROR:
             // FIXME: show error message in the UI
             break;
 
