@@ -5,13 +5,13 @@ const Mainloop = imports.mainloop;
 const Tweener = imports.tweener.tweener;
 
 // gi imports
-const Tb = imports.gi.Tb;
 const Clutter = imports.gi.Clutter;
 const ClutterGst = imports.gi.ClutterGst;
 const GLib = imports.gi.GLib;
 const Gtk = imports.gi.Gtk;
 const Mx = imports.gi.Mx;
 const Pango = imports.gi.Pango;
+const TheBoard = imports.gi.TheBoard;
 
 // ui imports
 const Thing = imports.ui.thing;
@@ -78,10 +78,10 @@ VideoThing.prototype = {
 
     _createVideoBox : function() {
         this._videoBox =
-            new Tb.Box({ orientation: Tb.BoxOrientation.HORIZONTAL,
-                         xAlign: Tb.BoxAlignment.FILL,
-                         yAlign: Tb.BoxAlignment.FILL,
-                         name: "video-thing-video-box" });
+            new TheBoard.Box({ orientation: TheBoard.BoxOrientation.HORIZONTAL,
+                               xAlign: TheBoard.BoxAlignment.FILL,
+                               yAlign: TheBoard.BoxAlignment.FILL,
+                               name: "video-thing-video-box" });
 
         this._videoBox.set_style(this._style);
 
@@ -92,15 +92,15 @@ VideoThing.prototype = {
 
     _createContentBox : function() {
         this._contentBox =
-            new Tb.Box({ orientation: Tb.BoxOrientation.VERTICAL,
-                         xAlign: Tb.BoxAlignment.FILL,
-                         yAlign: Tb.BoxAlignment.FILL,
-                         name: "video-thing-content-box" });
+            new TheBoard.Box({ orientation: TheBoard.BoxOrientation.VERTICAL,
+                               xAlign: TheBoard.BoxAlignment.FILL,
+                               yAlign: TheBoard.BoxAlignment.FILL,
+                               name: "video-thing-content-box" });
 
         this._contentBox.set_style(this._style);
 
         this._videoBox.append(this._contentBox,
-                                Tb.BoxPackFlags.EXPAND);
+                              TheBoard.BoxPackFlags.EXPAND);
     },
 
     _createStrip : function() {
@@ -110,15 +110,15 @@ VideoThing.prototype = {
                                   filename: _STRIP_CELL_IMAGE });
 
         this._videoBox.append(strip,
-                              Tb.BoxPackFlags.NONE);
+                              TheBoard.BoxPackFlags.NONE);
     },
 
     _createPlaybackBox : function() {
         this._playbackBox =
-            new Tb.Box({ orientation: Tb.BoxOrientation.VERTICAL,
-                         xAlign: Tb.BoxAlignment.FILL,
-                         yAlign: Tb.BoxAlignment.FILL,
-                         name: "video-thing-playback-box" });
+            new TheBoard.Box({ orientation: TheBoard.BoxOrientation.VERTICAL,
+                               xAlign: TheBoard.BoxAlignment.FILL,
+                               yAlign: TheBoard.BoxAlignment.FILL,
+                               name: "video-thing-playback-box" });
 
         this._playbackBox.set_style(this._style);
 
@@ -127,7 +127,7 @@ VideoThing.prototype = {
         this._createVideoBorderBox();
 
         this._contentBox.append(this._playbackBox,
-                                Tb.BoxPackFlags.EXPAND);
+                                TheBoard.BoxPackFlags.EXPAND);
     },
 
     _createVideo : function() {
@@ -139,27 +139,27 @@ VideoThing.prototype = {
                             Lang.bind(this, this._onVideoProgressChanged));
 
         this._playbackBox.append(this._video,
-                                 Tb.BoxPackFlags.EXPAND);
+                                 TheBoard.BoxPackFlags.EXPAND);
     },
 
     _createVideoControlsBox : function() {
         // This box is needed to add proper spacing between the
         // video controls and the edge of video playback frame
         let controlsBox =
-            new Tb.Box({ orientation: Tb.BoxOrientation.HORIZONTAL,
-                         xAlign: Tb.BoxAlignment.FILL,
-                         yAlign: Tb.BoxAlignment.CENTER,
-                         name: "video-thing-controls-box" });
+            new TheBoard.Box({ orientation: TheBoard.BoxOrientation.HORIZONTAL,
+                               xAlign: TheBoard.BoxAlignment.FILL,
+                               yAlign: TheBoard.BoxAlignment.CENTER,
+                               name: "video-thing-controls-box" });
 
         controlsBox.set_style(this._style);
 
         this._videoControlsBox =
-            new Tb.Box({ orientation: Tb.BoxOrientation.HORIZONTAL,
-                         xAlign: Tb.BoxAlignment.FILL,
-                         yAlign: Tb.BoxAlignment.CENTER,
-                         opacity: 0,
-                         visible: false,
-                         name: "video-thing-video-controls-box" });
+            new TheBoard.Box({ orientation: TheBoard.BoxOrientation.HORIZONTAL,
+                               xAlign: TheBoard.BoxAlignment.FILL,
+                               yAlign: TheBoard.BoxAlignment.CENTER,
+                               opacity: 0,
+                               visible: false,
+                               name: "video-thing-video-controls-box" });
 
         this._videoControlsBox.set_style(this._style);
 
@@ -168,14 +168,14 @@ VideoThing.prototype = {
         this._createTimeLabel();
 
         controlsBox.append(this._videoControlsBox,
-                           Tb.BoxPackFlags.EXPAND);
+                           TheBoard.BoxPackFlags.EXPAND);
 
         this._playbackBox.append(controlsBox,
-                                 Tb.BoxPackFlags.FIXED);
+                                 TheBoard.BoxPackFlags.FIXED);
 
         this._playbackBox.set_fixed_child_align(controlsBox,
-                                                Tb.BoxAlignment.FILL,
-                                                Tb.BoxAlignment.END);
+                                                TheBoard.BoxAlignment.FILL,
+                                                TheBoard.BoxAlignment.END);
     },
 
     _createPlayButton : function() {
@@ -190,7 +190,7 @@ VideoThing.prototype = {
                                            this._onPlayButtonToggled));
 
         this._videoControlsBox.append(this._playButton,
-                                      Tb.BoxPackFlags.NONE);
+                                      TheBoard.BoxPackFlags.NONE);
     },
 
     _createProgressBar : function() {
@@ -208,11 +208,11 @@ VideoThing.prototype = {
                                             this._onProgressBarButtonPressEvent));
 
         this._videoControlsBox.append(this._progressBar,
-                                      Tb.BoxPackFlags.EXPAND);
+                                      TheBoard.BoxPackFlags.EXPAND);
 
         this._videoControlsBox.set_child_align(this._progressBar,
-                                               Tb.BoxAlignment.FILL,
-                                               Tb.BoxAlignment.CENTER);
+                                               TheBoard.BoxAlignment.FILL,
+                                               TheBoard.BoxAlignment.CENTER);
     },
 
     _createTimeLabel : function() {
@@ -227,28 +227,28 @@ VideoThing.prototype = {
         this._updateTimeLabel();
 
         this._videoControlsBox.append(this._timeLabel,
-                                      Tb.BoxPackFlags.END);
+                                      TheBoard.BoxPackFlags.END);
 
         this._videoControlsBox.set_child_align(this._timeLabel,
-                                               Tb.BoxAlignment.START,
-                                               Tb.BoxAlignment.CENTER);
+                                               TheBoard.BoxAlignment.START,
+                                               TheBoard.BoxAlignment.CENTER);
     },
 
     _createVideoBorderBox : function() {
         this._videoBorderBox =
-            new Tb.Box({ orientation: Tb.BoxOrientation.HORIZONTAL,
-                         xAlign: Tb.BoxAlignment.FILL,
-                         yAlign: Tb.BoxAlignment.FILL,
-                         name: "video-thing-video-border-box" });
+            new TheBoard.Box({ orientation: TheBoard.BoxOrientation.HORIZONTAL,
+                               xAlign: TheBoard.BoxAlignment.FILL,
+                               yAlign: TheBoard.BoxAlignment.FILL,
+                               name: "video-thing-video-border-box" });
 
         this._videoBorderBox.set_style(this._style);
 
         this._playbackBox.append(this._videoBorderBox,
-                                 Tb.BoxPackFlags.FIXED);
+                                 TheBoard.BoxPackFlags.FIXED);
 
         this._playbackBox.set_fixed_child_align(this._videoBorderBox,
-                                                Tb.BoxAlignment.FILL,
-                                                Tb.BoxAlignment.FILL);
+                                                TheBoard.BoxAlignment.FILL,
+                                                TheBoard.BoxAlignment.FILL);
     },
 
     _createCaptionText : function() {
@@ -268,7 +268,7 @@ VideoThing.prototype = {
                                                          this._onCaptionTextChanged));
 
         this._contentBox.append(this._captionLabel,
-                                Tb.BoxPackFlags.NONE);
+                                TheBoard.BoxPackFlags.NONE);
     },
 
     _connectVideoSignals : function(fromState) {
